smileydelegate — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

# smileydelegate

class `camelot.view.controls.delegates.smileydelegate.` `SmileyDelegate`(parent, editable=True, icons=[('face-angel', Icon('tango/16x16/emotes/face-angel.png')), ('face-crying', Icon('tango/16x16/emotes/face-crying.png')), ('face-devilish', Icon('tango/16x16/emotes/face-devilish.png')), ('face-glasses', Icon('tango/16x16/emotes/face-glasses.png')), ('face-grin', Icon('tango/16x16/emotes/face-grin.png')), ('face-kiss', Icon('tango/16x16/emotes/face-kiss.png')), ('face-monkey', Icon('tango/16x16/emotes/face-monkey.png')), ('face-plain', Icon('tango/16x16/emotes/face-plain.png')), ('face-sad', Icon('tango/16x16/emotes/face-sad.png')), ('face-smile', Icon('tango/16x16/emotes/face-smile.png')), ('face-smile-big', Icon('tango/16x16/emotes/face-smile-big.png')), ('face-surprise', Icon('tango/16x16/emotes/face-surprise.png')), ('face-wink', Icon('tango/16x16/emotes/face-wink.png'))], **kwargs)

  Delegate for Smiley’s

  Field attributes supported by the delegate :

  > - editable
  > - icons

  By default, creates a SmileyEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - editable
  > - icons
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

Comments
blog comments powered by Disqus